{
  description = "flake for nixos-pulse";

  inputs = {
    nixpkgs = {
      url = "github:NixOS/nixpkgs/nixos-23.05";
    };
    tuxedo-nixos = {
      url = "github:blitz/tuxedo-nixos";
    };
    home-manager = {
      url = "github:nix-community/home-manager/release-23.05";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    emacs-overlay = {
      url = "github:nix-community/emacs-overlay";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    disko = {
      url = "github:nix-community/disko";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    nur = {
      url = "github:nix-community/NUR";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs = {
    self,
    home-manager,
    nixpkgs,
    tuxedo-nixos,
    emacs-overlay,
    disko,
    nur,
  }: let
    system = "x86_64-linux";
    customPkgs = import nixpkgs {
      system = "${system}";
      overlays = [emacs-overlay.overlay];
      config = {
        allowUnfree = true;
      };
    };
    pkgs = nixpkgs.legacyPackages.${system};
  in {
    formatter = {
      x86_64-linux = nixpkgs.legacyPackages.x86_64-linux.alejandra;
    };
    diskoConfigurations = {
      nixos-pulse = import ./disko.nix;
    };
    homeConfigurations = {
      "tristand" = home-manager.lib.homeManagerConfiguration {
        inherit pkgs;

        modules = [
          ./home.nix
          nur.hmModules.nur
          {
            _module.args.customPkgs = customPkgs;
            # inherit customPkgs;
            # pkgs.pkgs = customPkgs;
            # home-manager.useUserPackages = true;
            # home-manager.useGlobalPkgs = true;
          }
        ];
      };
    };
    nixosConfigurations = {
      nixos-pulse = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        modules = [
          ./configuration.nix
          ./users.nix
          ./disko.nix
          disko.nixosModules.disko
          home-manager.nixosModules.home-manager
          tuxedo-nixos.nixosModules.default
          nur.nixosModules.nur
          {
            _module.args.customPkgs = customPkgs;
            nixpkgs.pkgs = customPkgs;
            home-manager.useUserPackages = true;
            home-manager.useGlobalPkgs = true;
            hardware.tuxedo-control-center.enable = true;
            hardware.tuxedo-control-center.package = tuxedo-nixos.packages.x86_64-linux.default;
          }
        ];
      };
    };
  };
}
